Crate grid_2d[−][src]
Re-exports
pub use coord_2d; |
Structs
| Coord | General purpose coordinate |
| Grid | |
| IteratorLengthDifferentFromSize | |
| Size | A size cannot be created which would contain un-addressable cells.
That is, the maximum size has a width and height of one greater than the maximum |
Enums
| Get2Error |
Type Definitions
| CoordIter | |
| GridEnumerate | |
| GridEnumerateMut | |
| GridIntoEnumerate | |
| GridIntoIter | |
| GridIter | |
| GridIterMut | |
| GridRows | |
| GridRowsMut |